@@ -32,14 +32,15 @@ main(int argc, char **argv) {
     char infile[20];
     unsigned char header[4];
     unsigned int rows, cols;
-    int fd, i, j;
+    int fd;
+    unsigned int i, j;
     char *inbuf, *outbuf, *p, *q;
 
     set_progname(argv[0]);
 
     setlocale(LC_ALL, "");
-    bindtextdomain(PACKAGE, LOCALEDIR);
-    textdomain(PACKAGE);
+    bindtextdomain(PACKAGE_NAME, LOCALEDIR);
+    textdomain(PACKAGE_NAME);
 
     if (argc == 2 && !strcmp(argv[1], "-V"))
 	print_version_and_exit();
@@ -53,8 +54,18 @@ main(int argc, char **argv) {
 
     sprintf(infile, "/dev/vcsa%d", cons);
     fd = open(infile, O_RDONLY);
-    if (fd < 0 && cons == 0 && errno == ENOENT)
-      fd = open("/dev/vcsa", O_RDONLY);
+    if (fd < 0 && cons == 0 && errno == ENOENT) {
+      sprintf(infile, "/dev/vcsa");
+      fd = open(infile, O_RDONLY);
+    }
+    if (fd < 0 && errno == ENOENT) {
+      sprintf(infile, "/dev/vcs/a%d", cons);
+      fd = open(infile, O_RDONLY);
+    }
+    if (fd < 0 && cons == 0 && errno == ENOENT) {
+      sprintf(infile, "/dev/vcs/a");
+      fd = open(infile, O_RDONLY);
+    }
     if (fd < 0 || read(fd, header, 4) != 4)
       goto try_ioctl;
     rows = header[0];
@@ -64,7 +75,7 @@ main(int argc, char **argv) {
     inbuf = xmalloc(rows*cols*2);
     outbuf = xmalloc(rows*(cols+1));
 
-    if (read(fd, inbuf, rows*cols*2) != rows*cols*2) {
+    if (read(fd, inbuf, rows*cols*2) != (ssize_t) (rows*cols*2)) {
         fprintf(stderr, _("Error reading %s\n"), infile);
         exit(1);
     }
@@ -84,16 +95,23 @@ main(int argc, char **argv) {
 try_ioctl:
     {
 	struct winsize win;
-	char consnam[20];
+	char consnam[20], devfsconsnam[20];
 	unsigned char *screenbuf;
 
 	sprintf(consnam, "/dev/tty%d", cons);
-	if((fd = open(consnam, O_RDONLY)) < 0) {
+	fd = open(consnam, O_RDONLY);
+	if (fd < 0 && errno == ENOENT) {
+	    sprintf(devfsconsnam, "/dev/vc/%d", cons);
+	    fd = open(devfsconsnam, O_RDONLY);
+	    if (fd < 0)
+		errno = ENOENT;
+	}
+	if (fd < 0) {
 	    perror(consnam);
 	    fd = 0;
 	}
 
-	if (ioctl(fd,TIOCGWINSZ,&win)) {
+	if (ioctl(fd, TIOCGWINSZ, &win)) {
 	    perror("TIOCGWINSZ");
 	    exit(1);
 	}
@@ -127,7 +145,7 @@ try_ioctl:
 	}
 
 	outbuf = xmalloc(rows*(cols+1));
-	p = screenbuf + 2;
+	p = ((char *)screenbuf) + 2;
 	q = outbuf;
         for (i=0; i<rows; i++) {
 	    for (j=0; j<cols; j++)
