@@ -10,37 +10,38 @@
 #include <fcntl.h>
 #include <linux/kd.h>
 #include <sys/ioctl.h>
+#include "nls.h"
+#include "version.h"
 
-void
+static void attr_noreturn
 usage(void)
 {
-    fprintf(stderr, "\
-Usage:
-	setmetamode [ metabit | meta | bit | escprefix | esc | prefix ]
-Each vt has his own copy of this bit. Use
-	setmetamode [arg] < /dev/ttyn
-to change the settings of another vt.
-The setting before and after the change are reported.
-");
+    fprintf(stderr, _(
+"Usage:\n"
+"	setmetamode [ metabit | meta | bit | escprefix | esc | prefix ]\n"
+"Each vt has his own copy of this bit. Use\n"
+"	setmetamode [arg] < /dev/ttyn\n"
+"to change the settings of another vt.\n"
+"The setting before and after the change are reported.\n"
+));
     exit(1);
 }
 
-void
-report(meta) int meta;
-{
+static void
+report(int meta) {
     char *s;
 
     switch(meta) {
       case K_METABIT:
-	s = "Meta key sets high order bit\n";
+	s = _("Meta key sets high order bit\n");
 	break;
       case K_ESCPREFIX:
-	s = "Meta key gives Esc prefix\n";
+	s = _("Meta key gives Esc prefix\n");
 	break;
       default:
-	s = "Strange mode for Meta key?\n";
+	s = _("Strange mode for Meta key?\n");
     }
-    printf(s);
+    printf("%s", s);
 }
 
 struct meta {
@@ -58,14 +59,23 @@ struct meta {
 #define SIZE(a) (sizeof(a)/sizeof(a[0]))
 
 int
-main(argc,argv) int argc; char **argv;
-{
+main(int argc, char **argv) {
     char ometa, nmeta;
     struct meta *mp;
 
+    set_progname(argv[0]);
+
+    setlocale(LC_ALL, "");
+    bindtextdomain(PACKAGE_NAME, LOCALEDIR);
+    textdomain(PACKAGE_NAME);
+
+    if (argc == 2 && !strcmp(argv[1], "-V"))
+	print_version_and_exit();
+
     if (ioctl(0, KDGKBMETA, &ometa)) {
 	perror("KDGKBMETA");
-	fprintf(stderr, "Error reading current setting. Maybe stdin is not a VT?\n");
+	fprintf(stderr,
+		_("Error reading current setting. Maybe stdin is not a VT?\n"));
 	exit(1);
     }
 
@@ -75,23 +85,23 @@ main(argc,argv) int argc; char **argv;
     }
 
     nmeta = 0;			/* make gcc happy */
-    for (mp = metas; mp-metas < SIZE(metas); mp++) {
+    for (mp = metas; (unsigned) (mp-metas) < SIZE(metas); mp++) {
 	if(!strcmp(argv[1], mp->name)) {
 	    nmeta = mp->val;
 	    goto fnd;
 	}
     }
-    fprintf(stderr, "unrecognized argument: _%s_\n\n", argv[1]);
+    fprintf(stderr, _("unrecognized argument: _%s_\n\n"), argv[1]);
     usage();
 
   fnd:
-    printf("old state:    ");
+    printf(_("old state:    "));
     report(ometa);
     if (ioctl(0, KDSKBMETA, nmeta)) {
 	perror("KDSKBMETA");
 	exit(1);
     }
-    printf("new state:    ");
+    printf(_("new state:    "));
     report(nmeta);
     exit(0);
 }
